Package: openxlsx
Type: Package
Title: Read, Write and Edit XLSX Files
Version: 4.0.17
Date: 2017-03-09
Authors@R: c(
    person("Alexander", "Walker",
    email = "Alexander.Walker1989@gmail.com", role = c("aut", "cre")),
    person("Luca", "Braglia", role = "ctb"))
URL: https://github.com/awalker89/openxlsx
BugReports: https://github.com/awalker89/openxlsx/issues
Maintainer: Alexander Walker <Alexander.Walker1989@gmail.com>
Description: Simplifies the creation of Excel .xlsx files by providing a high
    level interface to writing, styling and editing worksheets. Through the use of
    'Rcpp', read/write times are comparable to the 'xlsx' and 'XLConnect' packages
    with the added benefit of removing the dependency on Java.
License: GPL-3
LinkingTo: Rcpp
Depends: R (>= 3.3.0)
Imports: methods, Rcpp, grDevices, stats, utils
VignetteBuilder: knitr
Suggests: knitr, testthat
RoxygenNote: 6.0.1.9000
Collate: 'CommentClass.R' 'HyperlinkClass.R' 'RcppExports.R'
        'class_definitions.R' 'StyleClass.R' 'WorkbookClass.R'
        'baseXML.R' 'borderFunctions.R' 'chartsheet_class.R'
        'conditional_formatting.R' 'helperFunctions.R' 'loadWorkbook.R'
        'openXL.R' 'openxlsx.R' 'openxlsxCoerce.R' 'readWorkbook.R'
        'sheet_data_class.R' 'workbook_column_widths.R'
        'workbook_read_workbook.R' 'workbook_write_data.R'
        'worksheet_class.R' 'wrappers.R' 'writeData.R'
        'writeDataTable.R' 'writexlsx.R'
NeedsCompilation: yes
Packaged: 2017-03-23 09:21:13 UTC; Alex
Author: Alexander Walker [aut, cre],
  Luca Braglia [ctb]
Repository: CRAN
Date/Publication: 2017-03-23 13:10:15 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-08-01 10:59:44 UTC; windows
Archs: x64
