# Generated by roxygen2: do not edit by hand

S3method("names<-",Workbook)
S3method(getNamedRegions,Workbook)
S3method(getNamedRegions,default)
S3method(names,Workbook)
S3method(read.xlsx,Workbook)
S3method(read.xlsx,default)
export("sheetVisibility<-")
export("sheetVisible<-")
export("worksheetOrder<-")
export(addFilter)
export(addStyle)
export(addWorksheet)
export(cloneWorksheet)
export(conditionalFormat)
export(conditionalFormatting)
export(convertFromExcelRef)
export(convertToDate)
export(convertToDateTime)
export(copyWorkbook)
export(createComment)
export(createNamedRegion)
export(createStyle)
export(createWorkbook)
export(dataValidation)
export(deleteData)
export(freezePane)
export(getBaseFont)
export(getDateOrigin)
export(getNamedRegions)
export(getSheetNames)
export(getStyles)
export(getTables)
export(insertImage)
export(insertPlot)
export(int2col)
export(loadWorkbook)
export(makeHyperlinkString)
export(mergeCells)
export(modifyBaseFont)
export(openXL)
export(pageBreak)
export(pageSetup)
export(protectWorkbook)
export(protectWorksheet)
export(read.xlsx)
export(readWorkbook)
export(removeCellMerge)
export(removeColWidths)
export(removeComment)
export(removeFilter)
export(removeRowHeights)
export(removeTable)
export(removeWorksheet)
export(renameWorksheet)
export(replaceStyle)
export(saveWorkbook)
export(setColWidths)
export(setFooter)
export(setHeader)
export(setHeaderFooter)
export(setRowHeights)
export(sheetVisibility)
export(sheetVisible)
export(sheets)
export(showGridLines)
export(worksheetOrder)
export(write.xlsx)
export(writeComment)
export(writeData)
export(writeDataTable)
export(writeFormula)
import(grDevices)
import(methods)
import(stats)
importFrom(Rcpp,sourceCpp)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,menu)
importFrom(utils,unzip)
importFrom(zip,zip)
useDynLib(openxlsx, .registration=TRUE)
